=============================
django-gaekit
=============================

.. image:: https://badge.fury.io/py/django-gaekit.png
    :target: http://badge.fury.io/py/django-gaekit
    
.. image:: https://travis-ci.org/georgewhewell/django-gaekit.png?branch=master
        :target: https://travis-ci.org/Beyond-Digital/django-gaekit

.. image:: https://pypip.in/d/django-gaekit/badge.png
        :target: https://crate.io/packages/django-gaekit?version=latest


Collection of backends, wrappers and utilities to enquicken django development on Google App Engine

Documentation
-------------

The full documentation is at http://django-gaekit.rtfd.org.

Quickstart
----------

For use with ::

    pip install django-gaekit

Then use it in a project::

	import gaekit

Features
--------

* TODO